summaryrefslogtreecommitdiff
path: root/src/include/taler_testing_lib.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2020-01-17 17:46:13 +0100
committerChristian Grothoff <christian@grothoff.org>2020-01-17 17:46:13 +0100
commit27457d94e4136d14c235aaea61214949842fc0aa (patch)
tree9abf4d5af8ca7cc1da6f1612bebf929cfd9ad744 /src/include/taler_testing_lib.h
parent9d2ff364dcb4777001c237c95e31657b36884d0e (diff)
downloadexchange-27457d94e4136d14c235aaea61214949842fc0aa.tar.gz
exchange-27457d94e4136d14c235aaea61214949842fc0aa.tar.bz2
exchange-27457d94e4136d14c235aaea61214949842fc0aa.zip
use properly typed merchant pub/priv key in trait
Diffstat (limited to 'src/include/taler_testing_lib.h')
-rw-r--r--src/include/taler_testing_lib.h43
1 files changed, 19 insertions, 24 deletions
diff --git a/src/include/taler_testing_lib.h b/src/include/taler_testing_lib.h
index 338eea654..ffe785658 100644
--- a/src/include/taler_testing_lib.h
+++ b/src/include/taler_testing_lib.h
@@ -2139,7 +2139,7 @@ struct TALER_TESTING_FreshCoinData
* Offer a _array_ of fresh coins.
*
* @param index which array of fresh coins to offer,
- * if there are multiple on offer. Tipically passed as
+ * if there are multiple on offer. Typically passed as
* zero.
* @param fresh_coins the array of fresh coins to offer
*
@@ -2255,74 +2255,69 @@ TALER_TESTING_make_trait_exchange_keys (unsigned int index,
/**
* Obtain a private key from a "peer". Used e.g. to obtain
* a merchant's priv to sign a /track request.
*
* @param cmd command that is offering the key.
- * @param index (tipically zero) which key to return if there
+ * @param index (typically zero) which key to return if there
* are multiple on offer.
* @param priv[out] set to the key coming from @a cmd.
* @return #GNUNET_OK on success.
*/
int
-TALER_TESTING_get_trait_peer_key (const struct TALER_TESTING_Command *cmd,
- unsigned int index,
- const struct
- GNUNET_CRYPTO_EddsaPrivateKey **priv);
+TALER_TESTING_get_trait_merchant_priv (const struct TALER_TESTING_Command *cmd,
+ unsigned int index,
+ const struct
+ TALER_MerchantPrivateKeyP **priv);
// FIXME: private get_trait_merchant_priv instead, rather have
// more traits with precise types than this!
/**
* Offer private key, typically done when CMD_1 needs it to
* sign a request.
*
- * @param index (tipically zero) which key to return if there are
+ * @param index (typically zero) which key to return if there are
* multiple on offer.
* @param priv which object should be offered.
* @return the trait.
*/
struct TALER_TESTING_Trait
-TALER_TESTING_make_trait_peer_key (unsigned int index,
- const struct
- GNUNET_CRYPTO_EddsaPrivateKey *priv);
-
-// FIXME: private get_trait_merchant_priv instead, rather have
-// more traits with precise types than this!
+TALER_TESTING_make_trait_merchant_priv (unsigned int index,
+ const struct
+ TALER_MerchantPrivateKeyP *priv);
/**
* Obtain a public key from a "peer". Used e.g. to obtain
* a merchant's public key to use backend's API.
*
* @param cmd command offering the key.
- * @param index (tipically zero) which key to return if there
+ * @param index (typically zero) which key to return if there
* are multiple on offer.
* @param pub[out] set to the key coming from @a cmd.
- *
* @return #GNUNET_OK on success.
*/
int
-TALER_TESTING_get_trait_peer_key_pub (const struct TALER_TESTING_Command *cmd,
+TALER_TESTING_get_trait_merchant_pub (const struct TALER_TESTING_Command *cmd,
unsigned int index,
const struct
- GNUNET_CRYPTO_EddsaPublicKey **pub);
+ TALER_MerchantPublicKeyP **pub);
/**
* Offer public key.
*
- * @param index (tipically zero) which key to return if there
+ * @param index (typically zero) which key to return if there
* are multiple on offer. NOTE: if one key is offered, it
* is mandatory to set this as zero.
* @param pub which object should be returned.
- *
* @return the trait.
*/
struct TALER_TESTING_Trait
-TALER_TESTING_make_trait_peer_key_pub (unsigned int index,
- struct GNUNET_CRYPTO_EddsaPublicKey *pub);
+TALER_TESTING_make_trait_merchant_pub (unsigned int index,
+ struct TALER_MerchantPublicKeyP *pub);
/**
@@ -2255,74 +2255,69 @@ TALER_TESTING_make_trait_exchange_keys (unsigned int index,
/**
- * Obtain a private key from a "peer". Used e.g. to obtain
+ * Obtain a private key from a "merchant". Used e.g. to obtain
* a merchant's priv to sign a /track request.
*
@@ -2255,74 +2255,69 @@ TALER_TESTING_make_trait_exchange_keys (unsigned int index,
// more traits with precise types than this!
/**
- * Offer private key, typically done when CMD_1 needs it to
+ * Offer private key of a merchant, typically done when CMD_1 needs it to
* sign a request.
*
@@ -2255,74 +2255,69 @@ TALER_TESTING_make_trait_exchange_keys (unsigned int index,
/**
- * Obtain a public key from a "peer". Used e.g. to obtain
+ * Obtain a public key from a "merchant". Used e.g. to obtain
* a merchant's public key to use backend's API.
*